#######################################
# REPLICATION FILE 
#
# --- Robustness: Logistic regression models ---
#
# "Right-Peopling" the State: Nationalism, Historical Legacies, and Ethnic Cleansing in Europe, 1886-2020
# Carl Müller-Crepon, Guy Schvitz, Lars-Erik Cederman
# November 2023
#
# Forthcoming, Journal of Conflict Resolution
#######################################

## Stub
stub <- "table_A2"


## Prep specification
these.treat <- list(c("tek.status"),
                    c("log(1+prec.homerule.yrsavg)"),
                    c("tek.status", "log(1+prec.homerule.yrsavg)"),
                    c( "log(1+prec.homerule.yrsavg)*tek.status"))

form.ls <- unlist(lapply(these.treat, function(t){
  lapply(list(c(contr.vars)), function(c){
    as.formula(paste("ethcl_onset_do", "~", 
             paste(c(t, c), collapse = " + ")) )
  })
}))

## Estimate fixest for SEs
model.ls.se <- lapply(form.ls, function(f){
  feglm(f,
        data=cgy.df[cgy.df$is.capitalrulegrp == 0,],
        family="binomial", glm.iter=50, fixef.rm="perfect",
        cluster = clust.vars)
})

## Estimate glm for stargazer
model.ls <- lapply(form.ls, function(f){
  glm(f,
      data=cgy.df[cgy.df$is.capitalrulegrp == 0,],
        family="binomial")
})

# Prepare Table
add.lines <- list(latex.addline("Country FE:", rep("no", length(model.ls))),
                  latex.addline("Year FE:", rep("no", length(model.ls))),
                  latex.addline("Controls:", rep(c("yes"), length(model.ls))))

# Save Table
fileConn <- file(file.path(tab.path, paste0(stub,".tex")))
writeLines(stargazer(model.ls,
                     se = lapply(model.ls.se, function(m){m$se}),
                     title="Ethnic Cleansing 1886--2020: Logit Models",
                     keep = c("Constant", "tek.status", "prec.homerule.yrsavg"),
                     # order = c(1,2,3,4),
                     # type = "text",
                     multicolumn = F,
                     column.labels = "Ethnic Cleansing (0/100)",
                     column.separate = length(model.ls), column.sep.width ="-10pt",
                     dep.var.caption = "",dep.var.labels = rep("", length(model.ls)),
                     covariate.labels = c("Intercept","Non-dominant TEK",
                                          "Dominant TEK",
                                          "Past home rule (yrs, log)", "Non-titular TEK x past home rule",
                                          "Titular TEK x past home rule"),
                     font.size = "scriptsize",
                     star.char = star.char,
                     notes.align = "c", label=stub, align =T,
                     add.lines = add.lines,digits = 3, intercept.top = T,intercept.bottom = F,
                     omit.stat = c("rsq","res.dev","ser"),
                     notes = latex.notes(.85, model = "Logistic regressions."),
                     notes.label = "", notes.append = F
), 
fileConn)
close(fileConn)
